-- phpMyAdmin SQL Dump
-- version 5.2.2
-- https://www.phpmyadmin.net/
--
-- Host: localhost:3306
-- Generation Time: Jan 26, 2026 at 05:01 PM
-- Server version: 11.4.9-MariaDB-cll-lve-log
-- PHP Version: 8.3.29

SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
START TRANSACTION;
SET time_zone = "+00:00";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;

--
-- Database: `clanrqdw_homes`
--

-- --------------------------------------------------------

--
-- Table structure for table `about`
--

CREATE TABLE `about` (
  `id` int(10) NOT NULL,
  `title` varchar(100) NOT NULL,
  `content` longtext NOT NULL,
  `image` varchar(300) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Dumping data for table `about`
--

INSERT INTO `about` (`id`, `title`, `content`, `image`) VALUES
(10, 'About Us', '<div id=\"pgc-w5d0dcc3394ac1-0-0\" class=\"panel-grid-cell\">\r\n<div id=\"panel-w5d0dcc3394ac1-0-0-0\" class=\"so-panel widget widget_sow-editor panel-first-child panel-last-child\" data-index=\"0\">\r\n<div class=\"so-widget-sow-editor so-widget-sow-editor-base\">\r\n<div class=\"siteorigin-widget-tinymce textwidget\">\r\n<p class=\"text_all_p_tag_css\">At Clan Group, we are more than just a real estate company; we are a dedicated team of professionals committed to providing unparalleled real estate services that meet your every need. With years of experience in the real estate industry, our mission is to help you find the perfect home or investment opportunity that aligns with your dreams and financial goals.</p>\r\n<div id=\"pgc-w5d0dcc3394ac1-0-0\" class=\"panel-grid-cell\">\r\n<div id=\"panel-w5d0dcc3394ac1-0-0-0\" class=\"so-panel widget widget_sow-editor panel-first-child panel-last-child\" data-index=\"0\">\r\n<div class=\"so-widget-sow-editor so-widget-sow-editor-base\">\r\n<div class=\"siteorigin-widget-tinymce textwidget\">\r\n<p class=\"text_all_p_tag_css\">Our team takes pride in offering personalized guidance throughout every step of your real estate journey, ensuring transparency and trust in every transaction.</p>\r\n<p class=\"text_all_p_tag_css\">We combine market expertise with modern technology to deliver results that exceed expectations. At Clan Group, your satisfaction isnï¿½t just our goalï¿½itï¿½s our promise for a lasting partnership built on integrity and excellence.</p>\r\n</div>\r\n</div>\r\n</div>\r\n</div>\r\n</div>\r\n</div>\r\n</div>\r\n</div>', 'b1.php');

-- --------------------------------------------------------

--
-- Table structure for table `admin`
--

CREATE TABLE `admin` (
  `aid` int(10) NOT NULL,
  `auser` varchar(50) NOT NULL,
  `aemail` varchar(50) NOT NULL,
  `apass` varchar(50) NOT NULL,
  `adob` date NOT NULL,
  `aphone` varchar(15) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Dumping data for table `admin`
--

INSERT INTO `admin` (`aid`, `auser`, `aemail`, `apass`, `adob`, `aphone`) VALUES
(9, 'developer', 'amanalideveloper@gmail.com', '3e5cb8315790f93fb49cc0e054799ad3647f61c0', '2000-04-16', '03002634510');

-- --------------------------------------------------------

--
-- Table structure for table `city`
--

CREATE TABLE `city` (
  `cid` int(50) NOT NULL,
  `cname` varchar(100) NOT NULL,
  `sid` int(50) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Dumping data for table `city`
--

INSERT INTO `city` (`cid`, `cname`, `sid`) VALUES
(16, 'Lahore', 16);

-- --------------------------------------------------------

--
-- Table structure for table `contact`
--

CREATE TABLE `contact` (
  `cid` int(50) NOT NULL,
  `name` varchar(100) NOT NULL,
  `email` varchar(100) NOT NULL,
  `phone` varchar(20) NOT NULL,
  `subject` varchar(100) NOT NULL,
  `message` varchar(250) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Dumping data for table `contact`
--

INSERT INTO `contact` (`cid`, `name`, `email`, `phone`, `subject`, `message`) VALUES
(10, 'Manuel Ireland', 'domains@indexersearch.pro', '745720303', 'clanhomes.com', 'Hello,\r\n\r\nYour clanhomes.com website needs to be indexed in Google Search Index for it  to appear in Web Search Results.\r\n\r\nSubmit  clanhomes.com at https://searchregister.net'),
(11, 'Alejandra Ferrell', 'domains@domainindex.pro', '41717844', 'clanhomes.com', 'Hello,\r\n\r\nHave your clanhomes.com website indexed in Google Search Index for it  to appear in Web Search Results.\r\n\r\nRegister clanhomes.com at https://searchregister.net'),
(12, 'Deepak Parcha', 'parchad78@gmail.com', '7678308208', 'Letâ€™s redesign your website for better leads and conversions', 'Hi,\r\n\r\nHope youâ€™re doing great!\r\n\r\n\r\n\r\nIâ€™m Deepak, a Website Design Consultant.\r\nWe specialize in creating stunning, responsive websites that help businesses stand out and generate more leads online.\r\n\r\n\r\nIf youâ€™d like, I can send a quick layou'),
(13, 'Jeannie Tijerina', 'jeannie.tijerina@gmail.com', '7936177600', 'Explore Great Deals at AliExpress', 'Find quality products at affordable prices. Browse the latest offers and enjoy easy, secure shopping on AliExpress.\r\n\r\nShop Now: https://mutualaffiliate.com/VaRSHO'),
(14, 'Alfie Savage', 'register@domains-submit.org', '4107512', 'clanhomes.com', 'Hi,\r\n\r\nAdd clanhomes.com website to Google Search Index to have it displayed in Search Results.\r\n\r\nRegister clanhomes.com at https://searchregister.net'),
(15, 'Anaya Prajapati', 'anaya.dgtlsolution@gmail.com', '9266141479', 'Missing out on traffic from Google?', 'Hi there http://clanhomes.com,\r\n \r\nI help businesses boost their website traffic and online visibility through effective SEO strategies. To get started, Iâ€™d love to take a quick look at your website and prepare a short report outlining key issues a'),
(16, 'Alexander Cruz', 'alexwebclicknova@gmail.com', '730157482', 'To support', 'Hello, I have a few questions about your company and services. Is someone available to answer? Thanks'),
(17, 'Maisie Deyoung', 'maisie.deyoung@gmail.com', '462970109', 'Improve Your Backlinks + Organic Visits', 'Grow your seo with trusted seo backlinks! \r\nBonusBacklinks.com - we deliver daily backlinks and drive organic traffic to your page EVERY DAY:\r\n\r\n+ Take 85% OFF\r\n+ Quality daily seo backlinks\r\n+ Organic website traffic\r\n+ Prices cheap as $1\r\n+ Bonus d'),
(18, 'Pilar Hedin', 'indexing@searches-clanhomes.com', '7052932674', 'clanhomes.com', 'Register clanhomes.com in Google Search Index to have it appear in websearch results.\r\nAdd clanhomes.com now at https://searchregister.info'),
(19, 'Emily Lenihan', 'join@seo4clanhomes.com', '2731067855', 'clanhomes.com', 'Hello,\r\n\r\nAdd clanhomes.com to SEODIRECTORY fort a better ranking in Web Search results order.\r\n\r\nhttps://seodir.pro'),
(20, 'Margot Kennedy', 'ai@list-clanhomes.com', '3375329717', 'clanhomes.com and ChatGPT', 'More and more people skip Google Search and ask ChatGPT to search for everything.\r\n\r\nAdd clanhomes.com to our AI-optimized directory now to increase your chances of being recommended.\r\n\r\nJoin now: https://AIREG.pro/'),
(21, 'Ernestine Ware', 'indexing@searches-clanhomes.com', '5404600453', 'clanhomes.com', 'Submit clanhomes.com to Google Index and have it appear in searches.\r\n\r\nAdd clanhomes.com now at https://searchregister.net'),
(22, 'Doug Ortiz', 'better@ai-clanhomes.com', '3745622925', 'clanhomes.com and A.I.', 'Users search using AI more & more.\r\n\r\nAdd clanhomes.com to our AI-optimized directory now to increase your chances of being recommended / mentioned.\r\n\r\nList it here:  https://AIREG.pro'),
(23, 'Danielle McKillop', 'daniellemckillop66@gmail.com', '6478381833', '2026 YouTube guide for clanhomes.com', 'Hi,\r\n\r\nI came across clanhomes.com and wanted to run something by you.\r\n\r\nMy team just finished a comprehensive 81-page YouTube guide for website owners - whether you are looking to launch a channel from scratch or grow an existing one through video.'),
(24, 'Joshua Skeats', 'indexing@searches-clanhomes.com', '4767874', 'clanhomes.com', '\r\n\r\nEnlist clanhomes.com in GoogleSearchIndex to have it displayed in search results!\r\n\r\nSubmit clanhomes.com now at https://searchregister.info'),
(25, 'Martin Sinnett', 'better@ai-clanhomes.com', '353800186', 'clanhomes.com and A.I.', 'Users search using AI more & more.\r\n\r\nAdd clanhomes.com to our AI-optimized directory now to increase your chances of being recommended / mentioned.\r\n\r\nList it here:  https://AIREG.pro');

-- --------------------------------------------------------

--
-- Table structure for table `feedback`
--

CREATE TABLE `feedback` (
  `fid` int(50) NOT NULL,
  `uid` int(50) NOT NULL,
  `fdescription` varchar(300) NOT NULL,
  `status` int(1) NOT NULL,
  `date` datetime NOT NULL DEFAULT current_timestamp()
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Dumping data for table `feedback`
--

INSERT INTO `feedback` (`fid`, `uid`, `fdescription`, `status`, `date`) VALUES
(7, 28, 'This is a demo feedback in order to use set it as Testimonial for the site. Just a simply dummy text rather than using lorem ipsum text lines.', 1, '2022-07-23 16:07:08'),
(10, 43, 'User Testing Message...\r\n', 0, '2025-10-22 16:39:51');

-- --------------------------------------------------------

--
-- Table structure for table `property`
--

CREATE TABLE `property` (
  `pid` int(50) NOT NULL,
  `title` varchar(200) NOT NULL,
  `Name` varchar(50) NOT NULL,
  `content` longtext NOT NULL,
  `refrance` varchar(50) NOT NULL,
  `paymenttype` varchar(100) NOT NULL,
  `Payment` varchar(100) NOT NULL,
  `Leadtype` varchar(50) NOT NULL,
  `address` varchar(50) NOT NULL,
  `contact` varchar(50) NOT NULL,
  `date` datetime NOT NULL DEFAULT current_timestamp(),
  `uid` int(50) NOT NULL,
  `status` varchar(10) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Dumping data for table `property`
--

INSERT INTO `property` (`pid`, `title`, `Name`, `content`, `refrance`, `paymenttype`, `Payment`, `Leadtype`, `address`, `contact`, `date`, `uid`, `status`) VALUES
(103, 'Apartment No. 370 Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1234567789', '2025-10-29 06:36:13', 43, 'Booked'),
(104, 'Apartment No. 370 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '12456789', '2025-10-29 06:37:49', 43, 'Booked'),
(105, 'Apartment No. 370 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:38:26', 43, 'Booked'),
(106, 'Apartment No. 371 Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:38:59', 43, 'Booked'),
(107, 'Apartment No. 371 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:41:09', 43, 'Booked'),
(108, 'Apartment No. 371 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:41:40', 43, 'Booked'),
(109, 'Apartment No. 372 Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:42:32', 43, 'Booked'),
(110, 'Apartment No. 372 Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:42:33', 43, 'Booked'),
(111, 'Apartment No. 372 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:43:01', 43, 'Booked'),
(112, 'Apartment No. 372 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:43:27', 43, 'Booked'),
(113, 'Apartment No. 373 Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:43:51', 43, 'Booked'),
(114, 'Apartment No. 373 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:44:36', 43, 'Booked'),
(115, 'Apartment No. 373 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:45:08', 43, 'Booked'),
(116, 'Apartment No. 374 Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:46:35', 43, 'Booked'),
(117, 'Apartment No. 374 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:48:06', 43, 'Booked'),
(118, 'Apartment No. 374 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:55:04', 43, 'Booked'),
(119, 'Apartment No. 375 Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:55:51', 43, 'Booked'),
(120, 'Apartment No. 375 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:56:13', 43, 'Booked'),
(121, 'Apartment No. 375 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:56:31', 43, 'Booked'),
(122, 'Apartment No. 376 Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:56:48', 43, 'Booked'),
(123, 'Apartment No. 376 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:57:07', 43, 'Booked'),
(124, 'Apartment No. 376 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:57:32', 43, 'Booked'),
(125, 'Apartment No. 377 Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:57:48', 43, 'Booked'),
(126, 'Apartment No. 377 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:58:04', 43, 'Booked'),
(127, 'Apartment No. 377 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:58:29', 43, 'Booked'),
(128, 'Apartment No. 378 Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:58:47', 43, 'Booked'),
(129, 'Apartment No. 378 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:59:06', 43, 'Booked'),
(130, 'Apartment No. 378 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:59:19', 43, 'Booked'),
(131, 'Apartment No. 379 Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:59:36', 43, 'Booked'),
(132, 'Apartment No. 379 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 06:59:51', 43, 'Booked'),
(133, 'Apartment No. 379 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:00:07', 43, 'Booked'),
(134, 'Apartment No. 379-A Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:00:23', 43, 'Booked'),
(135, 'Apartment No. 379-A 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:00:40', 43, 'Booked'),
(136, 'Apartment No. 379-A 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:00:55', 43, 'Booked'),
(137, 'Apartment No. 379-B Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:01:20', 43, 'Booked'),
(138, 'Apartment No. 379-B 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:01:45', 43, 'Booked'),
(139, 'Apartment No. 379-B 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:02:10', 43, 'Booked'),
(140, 'Apartment No. 379-C Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:02:32', 43, 'Booked'),
(141, 'Apartment No. 379-C 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:03:13', 43, 'Booked'),
(142, 'Apartment No. 379-C 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:03:35', 43, 'Booked'),
(143, 'Apartment No. 379-D Ground Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:03:58', 43, 'Booked'),
(144, 'Apartment No. 379-D 1st Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:04:19', 43, 'Booked'),
(145, 'Apartment No. 379-D 2nd Floor', 'CLAN', '', 'CLAN', 'Cash', '0', 'Walk-In', 'LAHORE', '1245768', '2025-10-29 07:04:55', 43, 'Booked'),
(146, 'Apartment No. 258 Ground Floor', 'Shamaila Iram ', '', 'Waqar Ahmed ', 'Cash', '50000', 'Cold-Call', 'LAHORE', '03354020337', '2025-10-29 08:23:56', 43, 'Booked'),
(147, 'Apartment No. 259 Ground Floor', 'Shamaila Iram ', '', 'Waqar Ahmed ', 'Cash', '50000', 'Cold-Call', 'LAHORE', '03354020337', '2025-10-29 08:25:34', 43, 'Booked'),
(148, 'Apartment No. 274 Ground Floor', 'Waseem Aslam', '', 'Rabia akram ', 'Cash', '1080000', 'Cold-Call', 'LAHORE', '03456529931', '2025-10-29 08:31:42', 43, 'Booked'),
(150, 'Apartment No. 287 Ground Floor', 'Waleed Iqbal ', '', 'Waleed Iqbal ', 'Cash', '0', 'Cold-Call', 'LAHORE', '2345768', '2025-11-02 03:23:27', 43, 'Booked'),
(151, 'Apartment No. 287 1st Floor', 'Waleed Iqbal ', '', 'Waleed Iqbal ', 'Online', '0', 'Cold-Call', 'LAHORE', '123456456', '2025-11-02 03:23:49', 43, 'Booked'),
(152, 'Apartment No. 287 2nd Floor', 'Waleed Iqbal ', '', 'Waleed Iqbal ', 'Online', '0', 'Cold-Call', 'LAHORE', '1243567', '2025-11-02 03:24:09', 43, 'Booked'),
(153, 'Apartment No. 286 Ground Floor', 'Adeel Asghar', '', 'Adeel Asghar', 'Cheque', '0', 'Cold-Call', 'LAHORE', '03004966675', '2025-11-02 03:24:37', 43, 'Booked'),
(154, 'Apartment No. 286 1st Floor', 'Adeel Asghar', '', 'Adeel Asghar', 'Cash', '0', 'Cold-Call', 'LAHORE', '03004966675', '2025-11-02 03:24:56', 43, 'Booked'),
(155, 'Apartment No. 286 2nd Floor', 'Adeel Asghar', '', 'Adeel Asghar', 'Cash', '0', 'Youtube', 'LAHORE', '03004966675', '2025-11-02 03:25:14', 43, 'Booked'),
(158, 'Apartment No. 256-A 2nd Floor', 'Arslan Gul', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '03004966675', '2025-11-02 03:26:10', 43, 'Hold'),
(159, 'Apartment No. 256-A 1st Floor', 'Arslan Gul', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '03004966675', '2025-11-02 03:26:29', 43, 'Hold'),
(160, 'Apartment No. 256-A Ground Floor', 'Arslan Gul', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '03004966675', '2025-11-02 03:26:46', 43, 'Hold'),
(161, 'Apartment No. 259 1st Floor', 'Muhammad Imran ', '', 'Dua ', 'Online', '50000', 'Cold-Call', 'LAHORE', '1246875566', '2025-11-02 03:28:32', 43, 'Booked'),
(162, 'Apartment No. 258 1st Floor', 'Zeeshan', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '1246875566', '2025-11-02 03:29:33', 43, 'Booked'),
(163, 'Apartment No. 260 Ground Floor', 'Noman Amir ', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '1246875566', '2025-11-02 03:30:14', 43, 'Booked'),
(164, 'Apartment No. 260 1st Floor', 'Noman Amir ', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '1246875566', '2025-11-02 03:31:30', 43, 'Booked'),
(165, 'Apartment No. 261 1st Floor', 'Imran Nasir ', '', 'Fahad Arslan ', 'Cash', '0', 'Cold-Call', 'LAHORE', '1246875566', '2025-11-02 03:33:27', 43, 'Booked'),
(166, 'Apartment No. 262 1st Floor', 'Talha Sageer ', '', 'Fahad Arslan ', 'Cash', '0', 'Cold-Call', 'LAHORE', '122345676', '2025-11-02 03:34:04', 43, 'Booked'),
(168, 'Apartment No. 261 2nd Floor', 'Fahd Zafar ', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '1246875566', '2025-11-02 03:34:52', 43, 'Booked'),
(192, 'Apartment No. 256 Ground Floor', 'Asim Asif', '', 'Hussain sales man', 'Cash', '9000000', 'Cold-Call', 'Ss', '03110444494', '2025-11-04 06:00:22', 43, 'Booked'),
(197, 'Apartment No. 289 Ground Floor', 'Malik Abubakar', '', 'Malik Abubakar', 'Cash', '0', 'Cold-Call', 'Lahore', '03077903034', '2025-11-10 05:29:42', 43, 'Booked'),
(198, 'Apartment No. 289 1st Floor', 'Malik Abubakar', '', 'Malik Abubakar', 'Cash', '0', 'Cold-Call', 'Lahore', '03077903034', '2025-11-10 05:29:58', 43, 'Booked'),
(199, 'Apartment No. 301 Ground Floor', 'Khadija Yaseen ', '', 'Abdul Wahab ', 'Cash', '1000000', 'Cold-Call', 'Lahore', '03244885331', '2025-11-10 05:33:03', 43, 'Booked'),
(200, 'Apartment No. 264 1st Floor', 'Waji ul Abbas ', '', 'Dua ', 'Online', '50000', 'Cold-Call', 'Lahore', '03007200610', '2025-11-14 04:05:53', 43, 'Booked'),
(201, 'Apartment No. 291 Ground Floor', 'Mian Muhammad Nouman ', '', 'Muhammad', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:37:41', 43, 'Booked'),
(202, 'Apartment No. 291 1st Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:38:02', 43, 'Booked'),
(203, 'Apartment No. 291 2nd Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:38:16', 43, 'Booked'),
(204, 'Apartment No. 292 Ground Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:38:30', 43, 'Booked'),
(205, 'Apartment No. 292 1st Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:38:41', 43, 'Booked'),
(206, 'Apartment No. 292 2nd Floor', 'Mian Muhammad Nouman ', '', 'Muhammad', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:38:56', 43, 'Booked'),
(207, 'Apartment No. 293 Ground Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:39:06', 43, 'Booked'),
(208, 'Apartment No. 293 1st Floor', 'Mian Muhammad Nouman ', '', 'Muhammad', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:39:17', 43, 'Booked'),
(209, 'Apartment No. 293 2nd Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:39:27', 43, 'Booked'),
(210, 'Apartment No. 294 Ground Floor', 'Mian Muhammad Nouman ', '', 'Muhammad', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:39:39', 43, 'Booked'),
(211, 'Apartment No. 294 1st Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:39:52', 43, 'Booked'),
(212, 'Apartment No. 294 2nd Floor', 'Mian Muhammad Nouman ', '', 'Muhammad', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:40:15', 43, 'Booked'),
(213, 'Apartment No. 295 Ground Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:40:27', 43, 'Booked'),
(214, 'Apartment No. 295 1st Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:40:41', 43, 'Booked'),
(215, 'Apartment No. 295 2nd Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:40:53', 43, 'Booked'),
(216, 'Apartment No. 296 Ground Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:41:03', 43, 'Booked'),
(217, 'Apartment No. 296 1st Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:41:16', 43, 'Booked'),
(218, 'Apartment No. 296 2nd Floor', 'Mian Muhammad Nouman ', '', 'Muhammad', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:41:28', 43, 'Booked'),
(219, 'Apartment No. 297 Ground Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:41:38', 43, 'Booked'),
(220, 'Apartment No. 297 1st Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:41:51', 43, 'Booked'),
(221, 'Apartment No. 297 2nd Floor', 'Mian Muhammad Nouman ', '', 'Muhammad', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:42:05', 43, 'Booked'),
(222, 'Apartment No. 298 Ground Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:42:17', 43, 'Booked'),
(223, 'Apartment No. 298 1st Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:42:29', 43, 'Booked'),
(224, 'Apartment No. 298 2nd Floor', 'Mian Muhammad Nouman ', '', 'Muhammad', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:42:40', 43, 'Booked'),
(225, 'Apartment No. 299 Ground Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:42:52', 43, 'Booked'),
(226, 'Apartment No. 299 2nd Floor', 'Mian Muhammad Nouman ', '', 'Muhammad', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:43:03', 43, 'Booked'),
(227, 'Apartment No. 299 1st Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:43:14', 43, 'Booked'),
(228, 'Apartment No. 300 Ground Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:43:27', 43, 'Booked'),
(229, 'Apartment No. 300 1st Floor', 'Mian Muhammad Nouman ', '', 'Muhammad ', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:43:40', 43, 'Booked'),
(230, 'Apartment No. 300 2nd Floor', 'Mian Muhammad Nouman ', '', 'Muhammad', 'Online', '0', 'Cold-Call', 'Lahore', '1234567789', '2025-11-15 07:43:52', 43, 'Booked'),
(231, 'Apartment No. 262 Ground Floor', 'Muhammad Rizwan ', '', 'Dua ', 'Online', '500000', 'Cold-Call', 'Lahore', '03008668797', '2025-11-22 04:33:56', 43, 'Booked'),
(232, 'Apartment No. 263 Ground Floor', 'Muhammad Ali ', '', 'Waqar Ahmed ', 'Online', '50000', 'Cold-Call', 'LAHORE', '03101479333', '2025-12-01 07:18:47', 43, 'Booked'),
(233, 'Apartment No. 257 Ground Floor', 'Ghazanfar Raja ', '', 'Fahad Arslan ', 'Online', '0', 'Cold-Call', 'LAHORE', '1246875566', '2025-12-02 07:23:04', 43, 'Booked'),
(234, 'Apartment No. 257 1st Floor', 'Ghazanfar Raja ', '', 'Fahad Arslan ', 'Cash', '0', 'Youtube', 'LAHORE', '1246875566', '2025-12-02 07:23:34', 43, 'Booked'),
(235, 'Apartment No. 257 2nd Floor', 'Ghazanfar Raja ', '', 'Fahad Arslan ', 'Cash', '0', 'Cold-Call', 'LAHORE', '1246875566', '2025-12-02 07:24:05', 43, 'Booked'),
(236, 'Apartment No. 261 Ground Floor', 'Muhammad Rizwan ', '', 'Fahad Arslan ', 'Cash', '0', 'Youtube', 'LAHORE', '1246875566', '2025-12-02 07:25:36', 43, 'Booked'),
(237, 'Apartment No. 264 Ground Floor', 'Umar Saboot', '', 'Fahad Arslan ', 'Cash', '0', 'Cold-Call', 'LAHORE', '1246875566', '2025-12-02 07:26:37', 43, 'Booked'),
(238, 'Apartment No. 265 Ground Floor', 'Fahad Zafar ', '', 'Fahad Arslan ', 'Cash', '0', 'Cold-Call', 'LAHORE', '1246875566', '2025-12-02 07:27:13', 43, 'Booked'),
(239, 'Apartment No. 285 Ground Floor', 'Adeel Asghar', '', 'Adeel Asghar', 'Cash', '0', 'Cold-Call', 'LAHORE', '1234564', '2025-12-23 06:48:21', 43, 'Booked'),
(240, 'Apartment No. 285 1st Floor', 'Adeel Asghar', '', 'Adeel Asghar', 'Cash', '0', 'Youtube', 'LAHORE', '1234564', '2025-12-23 06:48:38', 43, 'Booked'),
(241, 'Apartment No. 285 2nd Floor', 'Adeel Asghar', '', 'Adeel Asghar', 'Cash', '0', 'Cold-Call', 'LAHORE', '1234564', '2025-12-23 06:48:53', 43, 'Booked'),
(242, 'Apartment No. 287-A Ground Floor', 'Waleed Iqbal ', '', 'Waleed Iqbal ', 'Cash', '0', 'Cold-Call', 'LAHORE', '123454356', '2025-12-23 06:52:43', 43, 'Booked'),
(243, 'Apartment No. 287-A 1st Floor', 'Waleed Iqbal ', '', 'Waleed Iqbal ', 'Cash', '0', 'Cold-Call', 'LAHORE', '2134567', '2025-12-23 06:53:04', 43, 'Booked'),
(244, 'Apartment No. 287-A 2nd Floor', 'Waleed Iqbal ', '', 'Waleed Iqbal ', 'Cash', '0', 'Cold-Call', 'LAHORE', '2134567', '2025-12-23 06:53:19', 43, 'Booked'),
(245, 'Apartment No. 284 Ground Floor', 'Nabeel Akhtar ', '', 'Nabeel Akhtar ', 'Cash', '0', 'Cold-Call', 'LAHORE', '1243567', '2025-12-23 06:57:01', 43, 'Booked'),
(246, 'Apartment No. 284 1st Floor', 'Nabeel Akhtar ', '', 'Nabeel Akhtar ', 'Cash', '0', 'Cold-Call', 'LAHORE', '1243567', '2025-12-23 06:57:26', 43, 'Booked'),
(247, 'Apartment No. 284 2nd Floor', 'Nabeel Akhtar ', '', 'Nabeel Akhtar ', 'Cash', '0', 'Cold-Call', 'LAHORE', '1243567', '2025-12-23 06:57:42', 43, 'Booked'),
(248, 'Apartment No. 283 Ground Floor', 'Nabeel Akhtar ', '', 'Nabeel Akhtar ', 'Cash', '0', 'Cold-Call', 'LAHORE', '1243567', '2025-12-23 06:57:58', 43, 'Booked'),
(249, 'Apartment No. 283 1st Floor', 'Nabeel Akhtar ', '', 'Nabeel Akhtar ', 'Cash', '0', 'Cold-Call', 'LAHORE', '1243567', '2025-12-23 06:58:11', 43, 'Booked'),
(250, 'Apartment No. 283 2nd Floor', 'Nabeel Akhtar ', '', 'Nabeel Akhtar ', 'Cash', '0', 'Cold-Call', 'LAHORE', '1243567', '2025-12-23 07:00:35', 43, 'Booked'),
(251, 'Apartment No. 288 Ground Floor', 'Malik Abubakar ', '', 'Malik Abubakar', 'Cash', '0', 'Cold-Call', 'LAHORE', '03077903034', '2025-12-25 14:16:38', 43, 'Booked'),
(252, 'Apartment No. 288 1st Floor', 'Malik Abubakar ', '', 'Malik Abubakar', 'Cash', '0', 'Cold-Call', 'LAHORE', '03077903034', '2025-12-25 14:17:00', 43, 'Booked'),
(253, 'Apartment No. 288 2nd Floor', 'Malik Abubakar ', '', 'Malik Abubakar', 'Cash', '0', 'Cold-Call', 'LAHORE', '03077903034', '2025-12-25 14:17:16', 43, 'Booked'),
(254, 'Apartment No. 289 2nd Floor', 'Malik Abubakar ', '', 'Malik Abubakar', 'Cash', '0', 'Cold-Call', 'LAHORE', '03077903034', '2025-12-25 14:17:29', 43, 'Booked'),
(255, 'Apartment No. 290 Ground Floor', 'Muhammad Hanif ', '', 'Shahzaib sale Agent ', 'Cash', '0', 'Cold-Call', 'LAHORE', '03333366664', '2025-12-25 14:20:57', 43, 'Booked'),
(256, 'Apartment No. 290 1st Floor', 'Shumaila Niaz', '', 'Shahzaib sale Agent ', 'Cash', '0', 'Walk-In', 'LAHORE', '03333366664', '2025-12-25 14:21:19', 43, 'Booked'),
(257, 'Apartment No. 282 Ground Floor', 'Kashif Mumtaz ', '', 'kashif Mumtaz ', 'Cash', '0', 'Cold-Call', 'LAHORE', '12456757878', '2025-12-29 04:41:14', 43, 'Booked'),
(258, 'Apartment No. 282 1st Floor', 'Kashif Mumtaz ', '', 'kashif Mumtaz ', 'Cash', '0', 'Cold-Call', 'LAHORE', '12456757878', '2025-12-29 04:41:29', 43, 'Booked'),
(259, 'Apartment No. 282 2nd Floor', 'Kashif Mumtaz ', '', 'kashif Mumtaz ', 'Cash', '0', 'Cold-Call', 'LAHORE', '12456757878', '2025-12-29 04:41:44', 43, 'Booked'),
(260, 'Apartment No. 281 Ground Floor', 'Kashif Mumtaz ', '', 'kashif Mumtaz ', 'Cash', '0', 'Cold-Call', 'LAHORE', '12456757878', '2025-12-29 04:42:00', 43, 'Booked'),
(261, 'Apartment No. 281 1st Floor', 'Kashif Mumtaz ', '', 'kashif Mumtaz ', 'Cash', '0', 'Cold-Call', 'LAHORE', '12456757878', '2025-12-29 04:42:13', 43, 'Booked'),
(262, 'Apartment No. 281 2nd Floor', 'Kashif Mumtaz ', '', 'kashif Mumtaz ', 'Cash', '0', 'Cold-Call', 'LAHORE', '12456757878', '2025-12-29 04:42:28', 43, 'Booked'),
(263, 'Apartment No. 270 2nd Floor', 'Jahandur Durrani ', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '03004966675', '2025-12-31 04:20:48', 43, 'Booked'),
(264, 'Apartment No. 274 1st Floor', 'Azeem Subhani ', '', 'Moatisam Billah', 'Cash', '0', 'Cold-Call', 'LAHORE', '17866634919', '2026-01-06 07:09:31', 43, 'Booked'),
(265, 'Apartment No. 275 1st Floor', 'Azeem Subhani ', '', 'Moatisam Billah', 'Cash', '0', 'Cold-Call', 'LAHORE', '17866634919', '2026-01-06 07:09:48', 43, 'Booked'),
(266, 'Apartment No. 266 Ground Floor', 'Awais Shabir ', '', 'Malik Abubakar', 'Cash', '0', 'Cold-Call', 'Sheller Mehar rice mill opposite sony palace Alam ', '03238444205', '2026-01-06 08:18:47', 43, 'Booked'),
(267, 'Apartment No. 263 1st Floor', 'Touqeer Saba ', '', 'Miss Amina ', 'Cash', '50000', 'Cold-Call', 'LAHORE', '03334828966', '2026-01-17 03:40:57', 43, 'Booked'),
(268, 'Apartment No. 276 Ground Floor', 'Usama Billa', '', 'Moatisam Billah', 'Cash', '0', 'Cold-Call', 'LAHORE', '1234567789', '2026-01-21 04:37:22', 43, 'Booked'),
(269, 'Apartment No. 273 Ground Floor', 'Taha Masood', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '12344567567', '2026-01-21 04:39:14', 43, 'Booked'),
(270, 'Apartment No. 276 1st Floor', 'MOATISAM BILLAH ', '', 'Arslan Gul', 'Cash', '0', 'Walk-In', 'LAHORE', '124567', '2026-01-21 04:40:01', 43, 'Booked'),
(271, 'Apartment No. 276 2nd Floor', 'MOATISAM BILLAH ', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '1245678', '2026-01-21 04:40:25', 43, 'Booked'),
(272, 'Apartment No. 275 Ground Floor', 'MOATISAM BILLAH ', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '123456789', '2026-01-21 04:40:43', 43, 'Booked'),
(273, 'Apartment No. 275 2nd Floor', 'MOATISAM BILLAH ', '', 'Arslan Gul', 'Cash', '0', 'Cold-Call', 'LAHORE', '123456789', '2026-01-21 04:41:11', 43, 'Booked'),
(275, 'Office No. 01 Ground Floor', 'Mohsin ', '', 'ali', 'Cash', '0', 'Cold-Call', 'LAHORE', '03014555227', '2026-01-23 06:18:45', 43, 'Booked');

-- --------------------------------------------------------

--
-- Table structure for table `state`
--

CREATE TABLE `state` (
  `sid` int(50) NOT NULL,
  `sname` varchar(100) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Dumping data for table `state`
--

INSERT INTO `state` (`sid`, `sname`) VALUES
(16, 'Punjab');

-- --------------------------------------------------------

--
-- Table structure for table `user`
--

CREATE TABLE `user` (
  `uid` int(50) NOT NULL,
  `uname` varchar(100) NOT NULL,
  `uemail` varchar(100) NOT NULL,
  `uphone` varchar(20) NOT NULL,
  `upass` varchar(50) NOT NULL,
  `utype` varchar(50) NOT NULL,
  `uimage` varchar(300) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Dumping data for table `user`
--

INSERT INTO `user` (`uid`, `uname`, `uemail`, `uphone`, `upass`, `utype`, `uimage`) VALUES
(42, 'Etihad Marketing', 'sales@clandevelopers.com.pk', '03083845888', '0d20d1e2e7002fd0893582d7ea985c67f150ccb4', 'user', 'Aman Developer.png'),
(43, 'Clan Developers', 'info@clandevelopers.com.pk', '03083845888', 'b9f476d952d77d7ccbceaccfdce4bd5e8de4ffc7', 'user', 'Aman Developer.png'),
(45, 'Cc Hshs', 'dennysyahputra2900@gmail.com', '06959595969', '8dd7593b77cc5bdb110e2800165e157000cc7ebc', 'agent', 'fm3.php'),
(46, 'Hbbd brahim', 'lobi6261@gmail.com', '54578682566', 'b39abbe763440b02c231b2653ebd9da3ea78dcb1', 'user', 'He.php');

--
-- Indexes for dumped tables
--

--
-- Indexes for table `about`
--
ALTER TABLE `about`
  ADD PRIMARY KEY (`id`);

--
-- Indexes for table `admin`
--
ALTER TABLE `admin`
  ADD PRIMARY KEY (`aid`);

--
-- Indexes for table `city`
--
ALTER TABLE `city`
  ADD PRIMARY KEY (`cid`);

--
-- Indexes for table `contact`
--
ALTER TABLE `contact`
  ADD PRIMARY KEY (`cid`);

--
-- Indexes for table `feedback`
--
ALTER TABLE `feedback`
  ADD PRIMARY KEY (`fid`);

--
-- Indexes for table `property`
--
ALTER TABLE `property`
  ADD PRIMARY KEY (`pid`);

--
-- Indexes for table `state`
--
ALTER TABLE `state`
  ADD PRIMARY KEY (`sid`);

--
-- Indexes for table `user`
--
ALTER TABLE `user`
  ADD PRIMARY KEY (`uid`);

--
-- AUTO_INCREMENT for dumped tables
--

--
-- AUTO_INCREMENT for table `about`
--
ALTER TABLE `about`
  MODIFY `id` int(10) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=11;

--
-- AUTO_INCREMENT for table `admin`
--
ALTER TABLE `admin`
  MODIFY `aid` int(10) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=10;

--
-- AUTO_INCREMENT for table `city`
--
ALTER TABLE `city`
  MODIFY `cid` int(50) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=17;

--
-- AUTO_INCREMENT for table `contact`
--
ALTER TABLE `contact`
  MODIFY `cid` int(50) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=26;

--
-- AUTO_INCREMENT for table `feedback`
--
ALTER TABLE `feedback`
  MODIFY `fid` int(50) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=11;

--
-- AUTO_INCREMENT for table `property`
--
ALTER TABLE `property`
  MODIFY `pid` int(50) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=277;

--
-- AUTO_INCREMENT for table `state`
--
ALTER TABLE `state`
  MODIFY `sid` int(50) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=18;

--
-- AUTO_INCREMENT for table `user`
--
ALTER TABLE `user`
  MODIFY `uid` int(50) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=47;
COMMIT;

/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
